import * as ec2 from 'aws-cdk-lib/aws-ec2';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
/**
 * Properties for the VSCodeServer construct
 */
export interface VSCodeServerProps {
    /**
     * UserName for VSCode Server
     *
     * @default - participant
     */
    readonly vscodeUser?: string;
    /**
     * Password for VSCode Server
     *
     * @default - empty and will then be generated
     */
    readonly vscodePassword?: string;
    /**
     * VSCode Server EC2 instance name
     *
     * @default - VSCodeServer
     */
    readonly instanceName?: string;
    /**
     * VSCode Server EC2 instance volume size in GB
     *
     * @default - 40
     */
    readonly instanceVolumeSize?: number;
    /**
     * VSCode Server EC2 instance class
     *
     * @default - m7g
     */
    readonly instanceClass?: ec2.InstanceClass;
    /**
     * VSCode Server EC2 instance size
     *
     * @default - xlarge
     */
    readonly instanceSize?: ec2.InstanceSize;
    /**
     * VSCode Server EC2 operating system
     *
     * @default - Ubuntu-22
     */
    readonly instanceOperatingSystem?: LinuxFlavorType;
    /**
     * VSCode Server EC2 cpu architecture for the operating system
     *
     * @default - arm
     */
    readonly instanceCpuArchitecture?: LinuxArchitectureType;
    /**
     * Folder to open in VS Code server
     *
     * @default - /Workshop
     */
    readonly homeFolder?: string;
    /**
     * Base path for the application to be added to Nginx sites-available list
     *
     * @default - app
     */
    readonly devServerBasePath?: string;
    /**
     * Port for the DevServer
     *
     * @default - 8081
     */
    readonly devServerPort?: number;
    /**
     * Additional instance role policies
     *
     * @default - []
     */
    readonly additionalInstanceRolePolicies?: iam.PolicyStatement[];
    /**
     * Additional tags to add to the instance
     *
     * @default - {}
     */
    readonly additionalTags?: {
        [key: string]: string;
    };
}
/**
 * The flavor of linux you want to run vscode server on
 */
export declare enum LinuxFlavorType {
    /**
     * Ubuntu 22
     */
    UBUNTU_22 = "ubuntu22",
    /**
     * Ubuntu 24
     */
    UBUNTU_24 = "ubuntu24",
    /**
     * Amazon Linux 2023
     */
    AMAZON_LINUX_2023 = "al2023"
}
/**
 * The architecture of the cpu you want to run vscode server on
 */
export declare enum LinuxArchitectureType {
    /**
     * ARM architecture
     */
    ARM = "arm",
    /**
     * AMD64 architecture
     */
    AMD64 = "amd64"
}
/**
 * VSCodeServer - spin it up in under 10 minutes
 */
export declare class VSCodeServer extends Construct {
    /**
     * The name of the domain the server is reachable
     */
    readonly domainName: string;
    /**
     * The password to login to the server
     */
    readonly password: string;
    constructor(scope: Construct, id: string, props?: VSCodeServerProps);
}
